<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:tei="http://www.tei-c.org/ns/1.0" xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:xhtml="http://www.w3.org/1999/xhtml" exclude-result-prefixes="xs tei xhtml" version="2.0">

    <xsl:output doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
        doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd" method="xhtml"
        omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>

    <!-- run xslt over items in directory -->
    <!--<xsl:template match="list">
        <xsl:for-each select="item">
            <xsl:for-each select="collection(iri-to-uri(concat(@dir, '?select=*.xml')))">
                <xsl:variable name="outpath"
                    select="substring-before(tokenize(document-uri(.), '/')[last()], '.xml')"/>
                <xsl:result-document href="../HTML/{concat($outpath, '.html')}">
                    <xsl:apply-templates select="tei:TEI"/>
                </xsl:result-document>
            </xsl:for-each>
        </xsl:for-each>
    </xsl:template>-->

    <xsl:strip-space elements="*"/>


    <xsl:variable name="allDocuments" select="collection('../XML')"/>


    <xsl:template match="tei:TEI">

        <html>
            <head>
                <title>Court Depositions of South West England, 1500-1700</title>
                <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.3.1/jquery.min.js"/>

                <!-- http://fancyapps.com/fancybox/3 -->
                <script src="https://cdnjs.cloudflare.com/ajax/libs/fancybox/3.2.5/jquery.fancybox.min.js"/>
                <link rel="stylesheet" type="text/css"
                    href="https://cdnjs.cloudflare.com/ajax/libs/fancybox/3.2.5/jquery.fancybox.min.css"/>

                <link href="https://fonts.googleapis.com/css?family=Roboto" rel="stylesheet"/>

                <script type="text/javascript" src="../js/scripts.js"/>
                <link rel="stylesheet" type="text/css" href="../css/styles.css"/>
            </head>
            <body>
                <xsl:apply-templates select="tei:teiHeader"/>

                <xsl:apply-templates select="tei:text"/>
                <footer>
                    <div id="footer_inner">
                        <p>Prepared as part of the project <a
                            href="https://earlymodernwomenswork.wordpress.com" target="_blank">Women's Work in
                                Rural England, 1500-1700</a>.</p>
                        <p>
                            <a href="https://www.leverhulme.ac.uk" target="_blank">
                                <img src="../images/logos/leverhulme_trust.jpg"/>
                            </a>
                        </p>
                    </div>
                </footer>
            </body>
        </html>
    </xsl:template>

    <!-- header -->
    <xsl:template match="tei:teiHeader">
        <header>
            <h1>
                <a href="/womenswork/courtdepositions">Court Depositions of South West England, 1500-1700</a>
                <a class="logo" href="http://www.exeter.ac.uk" target="_blank">
                    <img src="../images/logos/uoe.gif"/>
                </a>
            </h1>
            <div id="banner">
                <img src="../images/theme/banner.jpg"/>
            </div>
            <h2>Court Depositions</h2>
            <div id="navigation">
                <xsl:variable name="urlself" select="//tei:TEI/@xml:id"/>
                <xsl:variable name="caseNum" select="$allDocuments//tei:seriesStmt/tei:idno"/>
                <select>
                    <xsl:for-each select="$caseNum">
                        <xsl:sort data-type="number" select="."/>
                        <xsl:variable name="names" select="//tei:fileDesc/tei:titleStmt/tei:title"/>
                        <xsl:variable name="url" select="//tei:TEI/@xml:id"/>
                        <xsl:choose>
                            <xsl:when test="$url = $urlself">
                                <option value="{$url}.html" selected=".">
                                    <xsl:text>Case </xsl:text>
                                    <xsl:value-of select="."/>
                                    <xsl:text>: </xsl:text>
                                    <xsl:value-of select="$names"/>
                                </option>
                            </xsl:when>
                            <xsl:otherwise>
                                <option value="{$url}.html">
                                    <xsl:text>Case </xsl:text>
                                    <xsl:value-of select="."/>
                                    <xsl:text>: </xsl:text>
                                    <xsl:value-of select="$names"/>
                                </option>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:for-each>
                </select>
            </div>

            <div id="metadata">
                <div id="metadata_inner">
                    <xsl:variable name="caseType" select="lower-case(//tei:profileDesc/tei:textClass/tei:keywords/tei:term)"/>
                    <p>Case type: <a href="/womenswork/courtdepositions/#{translate($caseType,' ','_')}"><xsl:value-of
                        select="//tei:profileDesc/tei:textClass/tei:keywords/tei:term"/></a></p>                    
                    <p>Summary: <xsl:apply-templates select="//tei:profileDesc/tei:abstract"
                            mode="headerRef"/>
                    </p>
                    <xsl:apply-templates select="//tei:sourceDesc"/>

                    <xsl:variable name="urlself" select="//tei:TEI/@xml:id"/>
                    <xsl:for-each select="$allDocuments">
                        <xsl:variable name="url" select="//tei:TEI/@xml:id"/>
                        <xsl:if test="$url = $urlself">
                            <p>
                                <a class="pdf" href="../downloads/{$url}.pdf">
                                    <xsl:text>Download transcriptions</xsl:text>
                                </a>
                            </p>
                        </xsl:if>

                    </xsl:for-each>

                </div>
            </div>
            <div id="key">
                <div id="key_inner">
                    <h4>Key</h4>
                    <p class="gloss"><em>Gloss:</em> definitions of key terminology.</p>
                    <p class="interpretation"><em>Interpretation:</em> matters of interest and importance relating to how evidence recorded in the depositions is analysed.</p>
                    <p class="technicality"><em>Technicalities of the court:</em> procedural information about the operation of the courts and the recording of depositional evidence.</p>
                </div>
            </div>
                <div id="images">
                    <xsl:apply-templates select="//tei:facsimile"/>
                </div>

        </header>
    </xsl:template>

    <xsl:template match="tei:msDesc">
        <p>Source: <xsl:apply-templates select="tei:msIdentifier/tei:institution"/>,
                <xsl:apply-templates select="tei:msIdentifier/tei:idno"/>
        </p>
    </xsl:template>

    <!--    images-->
    <xsl:template match="tei:graphic">
        <xsl:variable name="onestrip" select="substring-after(@url, '_')"/>
        <xsl:variable name="twostrip" select="substring-after($onestrip, '_')"/>
        <xsl:variable name="threestrip" select="substring-after($twostrip, '_')"/>
        <div>
            <a href="../images/fullsize/{@url}" data-fancybox="gallery"
                data-caption="a href='../images/fullsize/{@url}' target='_blank' class='external'Open in a new window">
                <img src="../images/thumbnails/{@url}"/>
            </a>
            <p>
                <xsl:value-of select="substring-before($threestrip, '.jpg')"/>
            </p>
        </div>
    </xsl:template>

    <!--body-->
    <xsl:template match="tei:div">
        <xsl:variable name="divNum" select="@n"/>
        <xsl:choose>
            <xsl:when test="@type = 'case'">
                <div id="original">
                    <div id="original_inner">
                        <h3>Original Spelling Transcription</h3>
                        <xsl:apply-templates/>
                    </div>
                </div>
            </xsl:when>
            <xsl:when test="@type = 'case-modernized'">
                <div id="modernized">
                    <div id="modernized_inner">
                        <h3>Modernized Spelling Transcription</h3>
                        <xsl:apply-templates/>
                    </div>
                </div>
            </xsl:when>
            <xsl:when test="@type = 'deposition'">
                <div class="deposition">
                    <h4>Deposition <xsl:value-of select="$divNum"/></h4>
                    <xsl:apply-templates/>
                </div>
            </xsl:when>
            <xsl:when test="@type = 'examination'">
                <div class="examination">
                    <h4>Examination <xsl:value-of select="$divNum"/></h4>
                    <xsl:apply-templates/>
                </div>
            </xsl:when>
            <xsl:when test="@type = 'informations'">
                <div class="informations">
                    <h4>Informations <xsl:value-of select="$divNum"/></h4>
                    <xsl:apply-templates/>
                </div>
            </xsl:when>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="tei:head">
        <h2>
            <xsl:apply-templates/>
        </h2>
    </xsl:template>

    <xsl:template match="tei:p">
        <xsl:choose>
            <xsl:when test="@rend='centre'">
                <p class="subtitle">
                    <xsl:apply-templates/>
                </p>
            </xsl:when>
            <xsl:otherwise>
                <p><xsl:apply-templates/></p>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="tei:signed">
        <p class="signature">
            <xsl:apply-templates/>
        </p>
    </xsl:template>

    <xsl:template match="tei:ex">
        <xsl:text>[</xsl:text>
        <xsl:apply-templates/>
        <xsl:text>]</xsl:text>
    </xsl:template>

    <xsl:template match="tei:supplied">
        <span class="supplied">
            <xsl:attribute name="title">
                <xsl:text>editorial addition</xsl:text>
            </xsl:attribute>
            <xsl:text>^</xsl:text>
            <xsl:apply-templates/>
            <xsl:text>^</xsl:text>
        </span>
    </xsl:template>

    <xsl:template match="tei:addition">
        <span class="scribaladdition">
            <xsl:attribute name="title">
                <xsl:text>scribal addition</xsl:text>
            </xsl:attribute>
            <xsl:text>^</xsl:text>
            <xsl:apply-templates/>
            <xsl:text>^</xsl:text>
        </span>
    </xsl:template>

    <xsl:template match="tei:del">
        <del>
            <xsl:apply-templates/>
        </del>
    </xsl:template>

    <xsl:template match="tei:gap">
        <span class="gap">
            <xsl:attribute name="title">
                <xsl:value-of select="@reason"/>
                <xsl:text>: </xsl:text>
                <xsl:value-of select="@extent"/>
                <xsl:text> missing</xsl:text>
            </xsl:attribute>
            <xsl:text>[...]</xsl:text>
        </span>
    </xsl:template>


    <!--notes/back-->

    <xsl:template match="tei:ref" xml:space="preserve">
        <xsl:variable name="refTarget" select="@target"/>
        <xsl:variable name="noteNum" select="substring-after(@target, '#')"/>
        <xsl:variable name="noteType" select="//tei:text/tei:back/tei:note[@xml:id = $noteNum]/@type"/>
        <a class="note {$noteType}" data-fancybox="" data-src="{$refTarget}"><xsl:attribute name="title"><xsl:text>View </xsl:text><xsl:value-of select="$noteType"/></xsl:attribute><xsl:apply-templates/></a></xsl:template>

    <xsl:template match="tei:ref" mode="headerRef">
        <a class="headerRef" href="{@target}.html">
            <xsl:apply-templates/>
        </a>
    </xsl:template>

    <xsl:template match="tei:back">
        <div id="notes">
            <xsl:apply-templates/>
        </div>
    </xsl:template>

    <xsl:template match="tei:note">
        <xsl:choose>
            <xsl:when test="@type = 'gloss'">
                <div id="{@xml:id}">
                    <h3 class="gloss">Gloss</h3>
                    <p>
                        <xsl:apply-templates/>
                    </p>
                </div>
            </xsl:when>
            <xsl:when test="@type = 'interpretation'">
                <div id="{@xml:id}">
                    <h3 class="interpretation">Interpretation</h3>
                    <p>
                        <xsl:apply-templates/>
                    </p>
                </div>
            </xsl:when>
            <xsl:when test="@type = 'technicality'">
                <div id="{@xml:id}">
                    <h3 class="technicality">Technicalities of the Court</h3>
                    <p>
                        <xsl:apply-templates/>
                    </p>
                </div>
            </xsl:when>
        </xsl:choose>
    </xsl:template>


</xsl:stylesheet>
